@@ -14,7 +14,7 @@ format_valuef <- function(digits) {
 
 #' @describeIn GMVAR print method
 #' @inheritParams plot.gmvar
-#' @param digits number of digits to be printed
+#' @param digits number of digits to be printed.
 #' @param summary_print if set to \code{TRUE} then the print
 #'   will include log-likelihood and information criteria values.
 #' @export
@@ -48,6 +48,7 @@ print.gmvar <- function(x, ..., digits=2, summary_print=FALSE) {
 
   if(summary_print == TRUE) {
     all_boldA_eigens <- get_boldA_eigens(gmvar)
+    all_omega_eigens <- get_omega_eigens(gmvar)
     cat(paste("log-likelihood:", format_value(gmvar$loglik)), "\n")
     cat(paste("AIC: ", format_value(IC$AIC)), "\n")
     cat(paste("HQIC:", format_value(IC$HQIC)), "\n")
@@ -61,7 +62,10 @@ print.gmvar <- function(x, ..., digits=2, summary_print=FALSE) {
   for(m in seq_len(M)) {
     count <- 1
     cat(paste("Regime", m), "\n")
-    if(summary_print == TRUE) cat(paste("Modulus of 'bold A' eigenvalues: ", paste0(format_value(all_boldA_eigens[[m]]), collapse=", ")),"\n")
+    if(summary_print == TRUE) {
+      cat(paste("Modulus of 'bold A' eigenvalues: ", paste0(format_value(all_boldA_eigens[[m]]), collapse=", ")),"\n")
+      cat(paste("Cov. matrix 'Omega' eigenvalues: ", paste0(format_value(all_omega_eigens[[m]]), collapse=", ")),"\n")
+    }
     cat(paste("Mixing weight:", format_value(alphas[m])), "\n")
     cat("Regime means:", paste0(format_value(all_mu[,m]), collapse=", "), "\n\n")
     df <- data.frame(Y=Y,
@@ -93,6 +97,9 @@ print.gmvar <- function(x, ..., digits=2, summary_print=FALSE) {
       cat("\n")
     }
   }
+  if(summary_print == TRUE) {
+    cat("Print approximate standard errors with the function 'print_std_errors'.\n")
+  }
   invisible(gmvar)
 }
 
@@ -100,10 +107,11 @@ print.gmvar <- function(x, ..., digits=2, summary_print=FALSE) {
 #' @title Summary print method from objects of class 'gmvarsum'
 #'
 #' @description \code{print.gmvarsum} is a print method for object \code{'gmvarsum'} generated
-#'   by \code{summary.gmvar()}.
+#'   by \code{summary.gmvar}.
 #'
-#' @param x object of class 'gmvarsum' generated by \code{summary.gmvar()}.
-#' @param ... currectly not used.
+#' @param x object of class 'gmvarsum' generated by \code{summary.gmvar}.
+#' @param ... currently not used.
+#' @param digits the number of digits to be printed.
 #' @examples
 #' # This example uses the data 'eurusd' which comes with the
 #' # package, but in a scaled form.
@@ -120,9 +128,10 @@ print.gmvar <- function(x, ..., digits=2, summary_print=FALSE) {
 #' print(sumry222)
 #' @export
 
-print.gmvarsum <- function(x, ...) {
+print.gmvarsum <- function(x, ..., digits) {
   gmvarsum <- x
-  print.gmvar(gmvarsum$gmvar, summary_print=TRUE)
+  if(missing(digits)) digits <- gmvarsum$digits
+  print.gmvar(gmvarsum$gmvar, ..., digits=digits, summary_print=TRUE)
   if(!is.null(gmvarsum$qrtest)) {
     cat("_____________________________________\n")
     cat("Quantile residual tests based on data\n\n")
@@ -135,7 +144,7 @@ print.gmvarsum <- function(x, ...) {
 #' @title print method for class 'gmvarpred' objects
 #'
 #' @description \code{print.gmvarpred} is print method for object generated
-#'  by \code{predict.gmvar()}.
+#'  by \code{predict.gmvar}.
 #'
 #' @inheritParams plot.gmvarpred
 #' @param digits number of decimals to print
@@ -163,32 +172,32 @@ print.gmvarpred <- function(x, ..., digits=2) {
   format_value <- format_valuef(digits)
 
   if(gmvarpred$pred_type == "cond_mean") {
-    cat("One-step-ahead prediction by exact conditional mean, no confidence intervals\n")
+    cat("One-step-ahead prediction by exact conditional mean, no prediction intervals\n")
     cat("Forecast:", paste0(format_value(gmvarpred$pred), collapse=", "), "\n")
 
-  } else if(gmvarpred$ci_type == "none") {
-    cat(paste0("Prediction by ", gmvarpred$pred_type, ", no confidence intervals"), "\n")
+  } else if(gmvarpred$pi_type == "none") {
+    cat(paste0("Prediction by ", gmvarpred$pred_type, ", no prediction intervals"), "\n")
     cat(paste0("Forecast ", gmvarpred$n_ahead, " steps ahead, based on ", gmvarpred$n_simu, " simulations\n"))
     print(gmvarpred$pred)
 
   } else {
-    cat(paste0("Prediction by ", gmvarpred$pred_type, ", ", gmvarpred$ci_type,
-               " confidence intervals with levels ", paste(gmvarpred$ci, collapse=", "), ""), "\n")
+    cat(paste0("Prediction by ", gmvarpred$pred_type, ", ", gmvarpred$pi_type,
+               " prediction intervals with levels ", paste(gmvarpred$pi, collapse=", "), ""), "\n")
     cat(paste0("Forecast ", gmvarpred$n_ahead, " steps ahead, based on ", gmvarpred$n_simu, " simulations\n"))
 
     cat("\n")
     q <- gmvarpred$q
-    conf_ints <- gmvarpred$conf_ints
+    pred_ints <- gmvarpred$pred_ints
     pred <- gmvarpred$pred
     pred_type <- gmvarpred$pred_type
     for(i1 in seq_len(gmvarpred$gmvar$model$d)) {
       cat(paste0("Component ", i1, ":"), "\n")
-      df <- as.data.frame(lapply(1:length(conf_ints), function(i2) format_value(conf_ints[[i2]][,i1])))
+      df <- as.data.frame(lapply(1:length(pred_ints), function(i2) format_value(pred_ints[[i2]][,i1])))
       names(df) <- q
       df[, pred_type] <- format_value(pred[,i1])
-      if(gmvarpred$ci_type == "two-sided") {
+      if(gmvarpred$pi_type == "two-sided") {
         new_order <- as.character(c(q[1:(length(q)/2)], pred_type, q[(length(q)/2 + 1):length(q)]))
-      } else if(gmvarpred$ci_type == "upper") {
+      } else if(gmvarpred$pi_type == "upper") {
         new_order <- as.character(c(pred_type, q))
       } else {
         new_order <- names(df)
@@ -203,8 +212,8 @@ print.gmvarpred <- function(x, ..., digits=2) {
 
 #' @describeIn quantile_residual_tests print method for class 'qrtest'
 #' @inheritParams print.gmvarpred
-#' @param x object of class \code{'qrtest'} generated by the function \code{quantile_residual_tests()}.
-#' @param ... currectly not used.
+#' @param x object of class \code{'qrtest'} generated by the function \code{quantile_residual_tests)}.
+#' @param ... currently not used.
 #' @export
 
 print.qrtest <- function(x, ..., digits=3) {
